export * from '@luzmo/embed';
import * as i0 from '@angular/core';
import { Injectable, EventEmitter, inject, NgZone, ElementRef, Component, CUSTOM_ELEMENTS_SCHEMA, ChangeDetectionStrategy, Input, Output, ViewChild, NgModule } from '@angular/core';
import { ReplaySubject, from } from 'rxjs';
import { JsonPipe, CommonModule } from '@angular/common';
import '@luzmo/shared-embed';

class NgxLuzmoDashboardService {
    constructor() {
        this._components = [];
        this.activeDashboardsSubject = new ReplaySubject(1);
    }
    getDashboards() {
        return this.activeDashboardsSubject.asObservable();
    }
    _emitActiveDashboardsSource() {
        this.activeDashboardsSubject.next(this._components);
    }
    _setComponentContext(componentContext) {
        if (!this._components.includes(componentContext)) {
            this._components.push(componentContext);
        }
    }
    // remove component context from array after unmounting
    _removeComponentContext(componentContext) {
        if (this._components.includes(componentContext)) {
            this._components = this._components.filter((context) => context !== componentContext);
        }
        this._emitActiveDashboardsSource();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.9", ngImport: i0, type: NgxLuzmoDashboardService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.9", ngImport: i0, type: NgxLuzmoDashboardService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.9", ngImport: i0, type: NgxLuzmoDashboardService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

const VERSION = '6.6.3-ngx-luzmo';

class NgxLuzmoDashboardComponent {
    get luzmoElement() {
        return this.luzmoElementRef.nativeElement;
    }
    constructor() {
        this.libVersion = VERSION;
        this.editMode = 'view';
        this.screenMode = 'auto';
        this.switchScreenModeOnResize = true;
        this.language = 'auto';
        this.editorLanguage = 'auto';
        this.embedMode = 'iframe';
        this.load = new EventEmitter();
        this.itemsRendered = new EventEmitter();
        this.customEvent = new EventEmitter();
        this.changedFilters = new EventEmitter();
        this.dashboardAction = new EventEmitter();
        this.exported = new EventEmitter();
        this.ngxLuzmoService = inject(NgxLuzmoDashboardService);
        this.ngZone = inject(NgZone);
        // To prevent having an error "Error: NG0909, at K.assertNotInAngularZone":
        globalThis.luzmoNgZone = this.ngZone;
    }
    ngAfterViewInit() {
        this.ngxLuzmoService._setComponentContext(this);
        this.luzmoElement.addEventListener('load', (payload) => {
            this.ngxLuzmoService._emitActiveDashboardsSource();
            this.load.emit(payload.detail);
        });
        this.luzmoElement.addEventListener('itemsRendered', (payload) => this.itemsRendered.emit(payload.detail));
        this.luzmoElement.addEventListener('customEvent', (payload) => this.customEvent.emit(payload.detail));
        this.luzmoElement.addEventListener('changedFilters', (payload) => this.changedFilters.emit(payload.detail));
        this.luzmoElement.addEventListener('dashboardAction', (payload) => this.dashboardAction.emit(payload.detail));
        this.luzmoElement.addEventListener('export', (payload) => this.exported.emit(payload.detail));
    }
    ngOnDestroy() {
        this.ngxLuzmoService._removeComponentContext(this);
    }
    getDashboards() {
        return from(this.luzmoElement.getDashboards());
    }
    getData(itemId) {
        return from(this.luzmoElement.getData(itemId));
    }
    getFilters() {
        return from(this.luzmoElement.getFilters());
    }
    setAuthorization(key, token) {
        return from(this.luzmoElement.setAuthorization(key, token));
    }
    refreshData(itemId) {
        return from(this.luzmoElement.refreshData(itemId));
    }
    reloadDashboard() {
        return from(this.luzmoElement.reloadDashboard());
    }
    exportDashboard(format) {
        return from(this.luzmoElement.exportDashboard(format));
    }
    getAccessibleDashboards() {
        return from(this.luzmoElement.getAccessibleDashboards());
    }
    setEditMode(editMode) {
        return from(this.luzmoElement.setEditMode(editMode));
    }
    setSelectedData(itemId, filters) {
        return from(this.luzmoElement.setSelectedData(itemId, filters));
    }
    addFilters(itemId, filters) {
        return from(this.luzmoElement.addFilters(itemId, filters));
    }
    setPreview(preview) {
        return from(this.luzmoElement.setPreview(preview));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.9", ngImport: i0, type: NgxLuzmoDashboardComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.9", type: NgxLuzmoDashboardComponent, isStandalone: true, selector: "luzmo-dashboard", inputs: { appServer: "appServer", apiHost: "apiHost", authToken: "authToken", authKey: "authKey", dashboardId: "dashboardId", itemId: "itemId", dashboardSlug: "dashboardSlug", editMode: "editMode", screenMode: "screenMode", switchScreenModeOnResize: "switchScreenModeOnResize", language: "language", editorLanguage: "editorLanguage", qeVersion: "qeVersion", timezoneId: "timezoneId", contextId: "contextId", theme: "theme", mainColor: "mainColor", accentColor: "accentColor", loaderBackground: "loaderBackground", loaderFontColor: "loaderFontColor", loaderSpinnerColor: "loaderSpinnerColor", loaderSpinnerBackground: "loaderSpinnerBackground", itemDimensions: "itemDimensions", embedMode: "embedMode" }, outputs: { load: "load", itemsRendered: "itemsRendered", customEvent: "customEvent", changedFilters: "changedFilters", dashboardAction: "dashboardAction", exported: "exported" }, viewQueries: [{ propertyName: "luzmoElementRef", first: true, predicate: ["luzmoElement"], descendants: true, read: ElementRef }], ngImport: i0, template: "<luzmo-embed-dashboard\n  #luzmoElement\n  [attr.appServer]=\"appServer\"\n  [attr.apiHost]=\"apiHost\"\n  [attr.authToken]=\"authToken\"\n  [attr.authKey]=\"authKey\"\n  [attr.dashboardId]=\"dashboardId\"\n  [attr.itemId]=\"itemId\"\n  [attr.dashboardSlug]=\"dashboardSlug\"\n  [attr.editMode]=\"editMode\"\n  [attr.screenMode]=\"screenMode\"\n  [attr.switchScreenModeOnResize]=\"switchScreenModeOnResize\"\n  [attr.language]=\"language\"\n  [attr.editorLanguage]=\"editorLanguage\"\n  [attr.qeVersion]=\"qeVersion\"\n  [attr.timezoneId]=\"timezoneId\"\n  [attr.contextId]=\"contextId\"\n  [attr.theme]=\"theme\"\n  [attr.mainColor]=\"mainColor\"\n  [attr.itemDimensions]=\"itemDimensions | json\"\n  [attr.accentColor]=\"accentColor\"\n  [attr.loaderBackground]=\"loaderBackground\"\n  [attr.loaderFontColor]=\"loaderFontColor\"\n  [attr.loaderSpinnerColor]=\"loaderSpinnerColor\"\n  [attr.loaderSpinnerBackground]=\"loaderSpinnerBackground\"\n  [attr.embedMode]=\"embedMode\"\n  [attr.libVersion]=\"libVersion\">\n</luzmo-embed-dashboard>\n", styles: [":host{display:block;position:relative;width:100%;height:100%}\n"], dependencies: [{ kind: "pipe", type: JsonPipe, name: "json" }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.9", ngImport: i0, type: NgxLuzmoDashboardComponent, decorators: [{
            type: Component,
            args: [{ schemas: [CUSTOM_ELEMENTS_SCHEMA], selector: 'luzmo-dashboard', changeDetection: ChangeDetectionStrategy.OnPush, imports: [
                        JsonPipe
                    ], standalone: true, template: "<luzmo-embed-dashboard\n  #luzmoElement\n  [attr.appServer]=\"appServer\"\n  [attr.apiHost]=\"apiHost\"\n  [attr.authToken]=\"authToken\"\n  [attr.authKey]=\"authKey\"\n  [attr.dashboardId]=\"dashboardId\"\n  [attr.itemId]=\"itemId\"\n  [attr.dashboardSlug]=\"dashboardSlug\"\n  [attr.editMode]=\"editMode\"\n  [attr.screenMode]=\"screenMode\"\n  [attr.switchScreenModeOnResize]=\"switchScreenModeOnResize\"\n  [attr.language]=\"language\"\n  [attr.editorLanguage]=\"editorLanguage\"\n  [attr.qeVersion]=\"qeVersion\"\n  [attr.timezoneId]=\"timezoneId\"\n  [attr.contextId]=\"contextId\"\n  [attr.theme]=\"theme\"\n  [attr.mainColor]=\"mainColor\"\n  [attr.itemDimensions]=\"itemDimensions | json\"\n  [attr.accentColor]=\"accentColor\"\n  [attr.loaderBackground]=\"loaderBackground\"\n  [attr.loaderFontColor]=\"loaderFontColor\"\n  [attr.loaderSpinnerColor]=\"loaderSpinnerColor\"\n  [attr.loaderSpinnerBackground]=\"loaderSpinnerBackground\"\n  [attr.embedMode]=\"embedMode\"\n  [attr.libVersion]=\"libVersion\">\n</luzmo-embed-dashboard>\n", styles: [":host{display:block;position:relative;width:100%;height:100%}\n"] }]
        }], ctorParameters: () => [], propDecorators: { appServer: [{
                type: Input
            }], apiHost: [{
                type: Input
            }], authToken: [{
                type: Input
            }], authKey: [{
                type: Input
            }], dashboardId: [{
                type: Input
            }], itemId: [{
                type: Input
            }], dashboardSlug: [{
                type: Input
            }], editMode: [{
                type: Input
            }], screenMode: [{
                type: Input
            }], switchScreenModeOnResize: [{
                type: Input
            }], language: [{
                type: Input
            }], editorLanguage: [{
                type: Input
            }], qeVersion: [{
                type: Input
            }], timezoneId: [{
                type: Input
            }], contextId: [{
                type: Input
            }], theme: [{
                type: Input
            }], mainColor: [{
                type: Input
            }], accentColor: [{
                type: Input
            }], loaderBackground: [{
                type: Input
            }], loaderFontColor: [{
                type: Input
            }], loaderSpinnerColor: [{
                type: Input
            }], loaderSpinnerBackground: [{
                type: Input
            }], itemDimensions: [{
                type: Input
            }], embedMode: [{
                type: Input
            }], load: [{
                type: Output
            }], itemsRendered: [{
                type: Output
            }], customEvent: [{
                type: Output
            }], changedFilters: [{
                type: Output
            }], dashboardAction: [{
                type: Output
            }], exported: [{
                type: Output
            }], luzmoElementRef: [{
                type: ViewChild,
                args: ['luzmoElement', { read: ElementRef }]
            }] } });

class NgxLuzmoVizItemComponent {
    get canFilterValue() {
        if (typeof this.canFilter === 'object') {
            return JSON.stringify(this.canFilter);
        }
        return this.canFilter;
    }
    constructor(elementRef, ngZone) {
        this.elementRef = elementRef;
        this.ngZone = ngZone;
        this.appServer = 'https://app.luzmo.com';
        this.apiHost = 'https://api.luzmo.com';
        this.slots = [];
        this.libVersion = VERSION;
        this.load = new EventEmitter();
        this.rendered = new EventEmitter();
        this.exported = new EventEmitter();
        this.changedFilters = new EventEmitter();
        this.customEvent = new EventEmitter();
        globalThis.luzmoNgZone = this.ngZone;
    }
    get luzmoVizElement() {
        return this.luzmoEmbedVizItem.nativeElement;
    }
    getFilters() {
        return this.luzmoVizElement.getFilters();
    }
    export(type = 'png') {
        return this.luzmoVizElement.export(type);
    }
    refreshData() {
        return this.luzmoVizElement.refreshData();
    }
    getData() {
        return this.luzmoVizElement.getData();
    }
    setAuthorization(key, token) {
        return this.luzmoVizElement.setAuthorization(key, token);
    }
    ngAfterViewInit() {
        if (this.luzmoEmbedVizItem) {
            this.luzmoEmbedVizItem.nativeElement.setAttribute('style', this.elementRef.nativeElement.style.cssText);
            this.luzmoEmbedVizItem.nativeElement.addEventListener('load', (payload) => this.load.emit(payload.detail));
            this.luzmoEmbedVizItem.nativeElement.addEventListener('rendered', (payload) => this.rendered.emit(payload.detail));
            this.luzmoEmbedVizItem.nativeElement.addEventListener('exported', (payload) => this.exported.emit(payload.detail));
            this.luzmoEmbedVizItem.nativeElement.addEventListener('changedFilters', (payload) => this.changedFilters.emit(payload.detail));
            this.luzmoEmbedVizItem.nativeElement.addEventListener('customEvent', (payload) => this.customEvent.emit(payload.detail));
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.9", ngImport: i0, type: NgxLuzmoVizItemComponent, deps: [{ token: i0.ElementRef }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.9", type: NgxLuzmoVizItemComponent, isStandalone: true, selector: "luzmo-viz-item", inputs: { appServer: "appServer", apiHost: "apiHost", slots: "slots", options: "options", type: "type", authKey: "authKey", authToken: "authToken", contextId: "contextId", canFilter: "canFilter", filters: "filters", dashboardId: "dashboardId", itemId: "itemId", selectedData: "selectedData", dashboardContentsVersion: "dashboardContentsVersion" }, outputs: { load: "load", rendered: "rendered", exported: "exported", changedFilters: "changedFilters", customEvent: "customEvent" }, viewQueries: [{ propertyName: "luzmoEmbedVizItem", first: true, predicate: ["luzmoEmbedVizItem"], descendants: true }], ngImport: i0, template: "<luzmo-embed-viz-item\n  #luzmoEmbedVizItem\n  [attr.appServer]=\"appServer\"\n  [attr.apiHost]=\"apiHost\"\n  [attr.authToken]=\"authToken\"\n  [attr.authKey]=\"authKey\"\n  [attr.slots]=\"slots | json\"\n  [attr.options]=\"options | json\"\n  [attr.type]=\"type\"\n  [attr.canFilter]=\"canFilterValue\"\n  [attr.contextId]=\"contextId\"\n  [attr.filters]=\"filters | json\"\n  [attr.itemId]=\"itemId\"\n  [attr.dashboardId]=\"dashboardId\"\n  [attr.libVersion]=\"libVersion\"\n  [attr.selectedData]=\"selectedData | json\"\n  [attr.dashboardContentsVersion]=\"dashboardContentsVersion\">\n</luzmo-embed-viz-item>\n", styles: [":host{display:block;width:100%;height:100%}\n"], dependencies: [{ kind: "pipe", type: JsonPipe, name: "json" }], changeDetection: i0.ChangeDetectionStrategy.Default }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.9", ngImport: i0, type: NgxLuzmoVizItemComponent, decorators: [{
            type: Component,
            args: [{ selector: 'luzmo-viz-item', standalone: true, schemas: [CUSTOM_ELEMENTS_SCHEMA], imports: [
                        JsonPipe
                    ], changeDetection: ChangeDetectionStrategy.Default, template: "<luzmo-embed-viz-item\n  #luzmoEmbedVizItem\n  [attr.appServer]=\"appServer\"\n  [attr.apiHost]=\"apiHost\"\n  [attr.authToken]=\"authToken\"\n  [attr.authKey]=\"authKey\"\n  [attr.slots]=\"slots | json\"\n  [attr.options]=\"options | json\"\n  [attr.type]=\"type\"\n  [attr.canFilter]=\"canFilterValue\"\n  [attr.contextId]=\"contextId\"\n  [attr.filters]=\"filters | json\"\n  [attr.itemId]=\"itemId\"\n  [attr.dashboardId]=\"dashboardId\"\n  [attr.libVersion]=\"libVersion\"\n  [attr.selectedData]=\"selectedData | json\"\n  [attr.dashboardContentsVersion]=\"dashboardContentsVersion\">\n</luzmo-embed-viz-item>\n", styles: [":host{display:block;width:100%;height:100%}\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.NgZone }], propDecorators: { appServer: [{
                type: Input
            }], apiHost: [{
                type: Input
            }], slots: [{
                type: Input
            }], options: [{
                type: Input
            }], type: [{
                type: Input
            }], authKey: [{
                type: Input
            }], authToken: [{
                type: Input
            }], contextId: [{
                type: Input
            }], canFilter: [{
                type: Input
            }], filters: [{
                type: Input
            }], dashboardId: [{
                type: Input
            }], itemId: [{
                type: Input
            }], selectedData: [{
                type: Input
            }], dashboardContentsVersion: [{
                type: Input
            }], load: [{
                type: Output
            }], rendered: [{
                type: Output
            }], exported: [{
                type: Output
            }], changedFilters: [{
                type: Output
            }], customEvent: [{
                type: Output
            }], luzmoEmbedVizItem: [{
                type: ViewChild,
                args: ['luzmoEmbedVizItem']
            }] } });

class NgxLuzmoIQChatComponent {
    constructor(elementRef, ngZone) {
        this.elementRef = elementRef;
        this.ngZone = ngZone;
        this.appServer = 'https://app.luzmo.com';
        this.apiHost = 'https://api.luzmo.com';
        this.libVersion = VERSION;
        globalThis.aydNgZone = this.ngZone;
    }
    get luzmoVizElement() {
        return this.luzmoIQChatItem.nativeElement;
    }
    ngAfterViewInit() {
        if (this.luzmoIQChatItem) {
            this.luzmoIQChatItem.nativeElement.setAttribute('style', this.elementRef.nativeElement.style.cssText);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.9", ngImport: i0, type: NgxLuzmoIQChatComponent, deps: [{ token: i0.ElementRef }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.9", type: NgxLuzmoIQChatComponent, isStandalone: true, selector: "luzmo-iq-chat", inputs: { appServer: "appServer", apiHost: "apiHost", options: "options", authKey: "authKey", authToken: "authToken", initialSuggestionsDatasetId: "initialSuggestionsDatasetId", aiEndPoint: "aiEndPoint", availableDatasets: "availableDatasets" }, viewQueries: [{ propertyName: "luzmoIQChatItem", first: true, predicate: ["luzmoIQChatItem"], descendants: true }], ngImport: i0, template: "<luzmo-iq-embed-chat\n  #luzmoIQChatItem\n  [attr.appServer]=\"appServer\"\n  [attr.apiHost]=\"apiHost\"\n  [attr.authToken]=\"authToken\"\n  [attr.authKey]=\"authKey\"\n  [attr.options]=\"options | json\"\n  [attr.libVersion]=\"libVersion\"\n  [attr.initialSuggestionsDatasetId]=\"initialSuggestionsDatasetId | json\"\n  [attr.aiEndPoint]=\"aiEndPoint\"\n  [attr.availableDatasets]=\"availableDatasets | json\">\n    <ng-content select=\"[slot='custom-chat-widget-content']\"></ng-content>\n</luzmo-iq-embed-chat>\n", styles: [":host{display:block;width:100%;height:100%}\n"], dependencies: [{ kind: "pipe", type: JsonPipe, name: "json" }], changeDetection: i0.ChangeDetectionStrategy.Default }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.9", ngImport: i0, type: NgxLuzmoIQChatComponent, decorators: [{
            type: Component,
            args: [{ selector: 'luzmo-iq-chat', standalone: true, schemas: [CUSTOM_ELEMENTS_SCHEMA], imports: [
                        JsonPipe
                    ], changeDetection: ChangeDetectionStrategy.Default, template: "<luzmo-iq-embed-chat\n  #luzmoIQChatItem\n  [attr.appServer]=\"appServer\"\n  [attr.apiHost]=\"apiHost\"\n  [attr.authToken]=\"authToken\"\n  [attr.authKey]=\"authKey\"\n  [attr.options]=\"options | json\"\n  [attr.libVersion]=\"libVersion\"\n  [attr.initialSuggestionsDatasetId]=\"initialSuggestionsDatasetId | json\"\n  [attr.aiEndPoint]=\"aiEndPoint\"\n  [attr.availableDatasets]=\"availableDatasets | json\">\n    <ng-content select=\"[slot='custom-chat-widget-content']\"></ng-content>\n</luzmo-iq-embed-chat>\n", styles: [":host{display:block;width:100%;height:100%}\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.NgZone }], propDecorators: { appServer: [{
                type: Input
            }], apiHost: [{
                type: Input
            }], options: [{
                type: Input
            }], authKey: [{
                type: Input
            }], authToken: [{
                type: Input
            }], initialSuggestionsDatasetId: [{
                type: Input
            }], aiEndPoint: [{
                type: Input
            }], availableDatasets: [{
                type: Input
            }], luzmoIQChatItem: [{
                type: ViewChild,
                args: ['luzmoIQChatItem']
            }] } });

class NgxLuzmoIQAnswerComponent {
    constructor(elementRef, ngZone) {
        this.elementRef = elementRef;
        this.ngZone = ngZone;
        this.appServer = 'https://app.luzmo.com';
        this.apiHost = 'https://api.luzmo.com';
        this.libVersion = VERSION;
        globalThis.aydNgZone = this.ngZone;
    }
    get luzmoVizElement() {
        return this.luzmoIQAnswerItem.nativeElement;
    }
    ngAfterViewInit() {
        if (this.luzmoIQAnswerItem) {
            this.luzmoIQAnswerItem.nativeElement.setAttribute('style', this.elementRef.nativeElement.style.cssText);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.9", ngImport: i0, type: NgxLuzmoIQAnswerComponent, deps: [{ token: i0.ElementRef }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.9", type: NgxLuzmoIQAnswerComponent, isStandalone: true, selector: "luzmo-iq-answer", inputs: { appServer: "appServer", apiHost: "apiHost", options: "options", messages: "messages", authKey: "authKey", authToken: "authToken", aiEndPoint: "aiEndPoint" }, viewQueries: [{ propertyName: "luzmoIQAnswerItem", first: true, predicate: ["luzmoIQAnswerItem"], descendants: true }], ngImport: i0, template: "<luzmo-iq-embed-answer\n  #luzmoIQAnswerItem\n  [attr.appServer]=\"appServer\"\n  [attr.apiHost]=\"apiHost\"\n  [attr.authToken]=\"authToken\"\n  [attr.authKey]=\"authKey\"\n  [attr.options]=\"options | json\"\n  [attr.libVersion]=\"libVersion\"\n  [attr.messages]=\"messages | json\"\n  [attr.aiEndPoint]=\"aiEndPoint\">\n</luzmo-iq-embed-answer>\n", styles: [":host{display:block;width:100%;height:100%}\n"], dependencies: [{ kind: "pipe", type: JsonPipe, name: "json" }], changeDetection: i0.ChangeDetectionStrategy.Default }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.9", ngImport: i0, type: NgxLuzmoIQAnswerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'luzmo-iq-answer', standalone: true, schemas: [CUSTOM_ELEMENTS_SCHEMA], imports: [
                        JsonPipe
                    ], changeDetection: ChangeDetectionStrategy.Default, template: "<luzmo-iq-embed-answer\n  #luzmoIQAnswerItem\n  [attr.appServer]=\"appServer\"\n  [attr.apiHost]=\"apiHost\"\n  [attr.authToken]=\"authToken\"\n  [attr.authKey]=\"authKey\"\n  [attr.options]=\"options | json\"\n  [attr.libVersion]=\"libVersion\"\n  [attr.messages]=\"messages | json\"\n  [attr.aiEndPoint]=\"aiEndPoint\">\n</luzmo-iq-embed-answer>\n", styles: [":host{display:block;width:100%;height:100%}\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.NgZone }], propDecorators: { appServer: [{
                type: Input
            }], apiHost: [{
                type: Input
            }], options: [{
                type: Input
            }], messages: [{
                type: Input
            }], authKey: [{
                type: Input
            }], authToken: [{
                type: Input
            }], aiEndPoint: [{
                type: Input
            }], luzmoIQAnswerItem: [{
                type: ViewChild,
                args: ['luzmoIQAnswerItem']
            }] } });

class NgxLuzmoDashboardModule {
    /**
     * @deprecated Will be removed in next major release.
     */
    static forRoot() {
        return {
            ngModule: NgxLuzmoDashboardModule,
            providers: [NgxLuzmoDashboardService]
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.9", ngImport: i0, type: NgxLuzmoDashboardModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.9", ngImport: i0, type: NgxLuzmoDashboardModule, imports: [CommonModule, NgxLuzmoDashboardComponent, NgxLuzmoVizItemComponent, NgxLuzmoIQChatComponent, NgxLuzmoIQAnswerComponent], exports: [NgxLuzmoDashboardComponent, NgxLuzmoVizItemComponent, NgxLuzmoIQChatComponent, NgxLuzmoIQAnswerComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.9", ngImport: i0, type: NgxLuzmoDashboardModule, imports: [CommonModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.9", ngImport: i0, type: NgxLuzmoDashboardModule, decorators: [{
            type: NgModule,
            args: [{
                    schemas: [CUSTOM_ELEMENTS_SCHEMA],
                    imports: [CommonModule, NgxLuzmoDashboardComponent, NgxLuzmoVizItemComponent, NgxLuzmoIQChatComponent, NgxLuzmoIQAnswerComponent],
                    exports: [NgxLuzmoDashboardComponent, NgxLuzmoVizItemComponent, NgxLuzmoIQChatComponent, NgxLuzmoIQAnswerComponent]
                }]
        }] });

/*
 * Public API Surface of ngx-luzmo
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxLuzmoDashboardComponent, NgxLuzmoDashboardModule, NgxLuzmoDashboardService, NgxLuzmoIQAnswerComponent, NgxLuzmoIQChatComponent, NgxLuzmoVizItemComponent };
//# sourceMappingURL=luzmo-ngx-embed.mjs.map
