"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ngAdd = ngAdd;
const core_1 = require("@angular-devkit/core");
const schematics_1 = require("@angular-devkit/schematics");
const tasks_1 = require("@angular-devkit/schematics/tasks");
const change_1 = require("@schematics/angular/utility/change");
const ast_utils_1 = require("@schematics/angular/utility/ast-utils");
const ts = require("@schematics/angular/third_party/github.com/Microsoft/TypeScript/lib/typescript");
// Just return the tree
function ngAdd(options) {
    return (0, schematics_1.chain)([
        (tree, context) => {
            context.addTask(new tasks_1.NodePackageInstallTask());
            return tree;
        },
        addModule(options.project)
    ]);
}
function createHost(tree) {
    return {
        readFile(path) {
            return __awaiter(this, void 0, void 0, function* () {
                const data = tree.read(path);
                if (!data) {
                    throw new schematics_1.SchematicsException('File not found.');
                }
                return core_1.virtualFs.fileBufferToString(data);
            });
        },
        writeFile(path, data) {
            return __awaiter(this, void 0, void 0, function* () {
                return tree.overwrite(path, data);
            });
        },
        isDirectory(path) {
            return __awaiter(this, void 0, void 0, function* () {
                return !tree.exists(path) && tree.getDir(path).subfiles.length > 0;
            });
        },
        isFile(path) {
            return __awaiter(this, void 0, void 0, function* () {
                return tree.exists(path);
            });
        }
    };
}
function addSymbolToNgModuleMetadata(source, ngModulePath, metadataField, symbolName, importPath = null) {
    const nodes = (0, ast_utils_1.getDecoratorMetadata)(source, 'Component', '@angular/core');
    const node = nodes[0];
    // Find the decorator declaration.
    if (!node || !ts.isObjectLiteralExpression(node)) {
        return [];
    }
    // Get all the children property assignment of object literals.
    const matchingProperties = (0, ast_utils_1.getMetadataField)(node, metadataField);
    if (matchingProperties.length == 0) {
        // We haven't found the field in the metadata declaration. Insert a new field.
        let position;
        let toInsert;
        if (node.properties.length == 0) {
            position = node.getEnd() - 1;
            toInsert = `\n  ${metadataField}: [\n${core_1.tags.indentBy(4) `${symbolName}`}\n  ]\n`;
        }
        else {
            const childNode = node.properties[node.properties.length - 1];
            position = childNode.getEnd();
            // Get the indentation of the last element, if any.
            const text = childNode.getFullText(source);
            const matches = text.match(/^(\r?\n)(\s*)/);
            if (matches) {
                toInsert =
                    `,${matches[0]}${metadataField}: [${matches[1]}` +
                        `${core_1.tags.indentBy(matches[2].length + 2) `${symbolName}`}${matches[0]}]`;
            }
            else {
                toInsert = `, ${metadataField}: [${symbolName}]`;
            }
        }
        if (importPath !== null) {
            return [
                new change_1.InsertChange(ngModulePath, position, toInsert),
                (0, ast_utils_1.insertImport)(source, ngModulePath, symbolName.replace(/\..*$/, ''), importPath),
            ];
        }
        else {
            return [new change_1.InsertChange(ngModulePath, position, toInsert)];
        }
    }
    const assignment = matchingProperties[0];
    // If it's not an array, nothing we can do really.
    if (!ts.isPropertyAssignment(assignment) ||
        !ts.isArrayLiteralExpression(assignment.initializer)) {
        return [];
    }
    let expression;
    const assignmentInit = assignment.initializer;
    const elements = assignmentInit.elements;
    if (elements.length) {
        const symbolsArray = elements.map((node) => core_1.tags.oneLine `${node.getText()}`);
        if (symbolsArray.includes(core_1.tags.oneLine `${symbolName}`)) {
            return [];
        }
        expression = elements[elements.length - 1];
    }
    else {
        expression = assignmentInit;
    }
    let toInsert;
    let position = expression.getEnd();
    if (ts.isArrayLiteralExpression(expression)) {
        // We found the field but it's empty. Insert it just before the `]`.
        position--;
        toInsert = `\n${core_1.tags.indentBy(4) `${symbolName}`}\n  `;
    }
    else {
        // Get the indentation of the last element, if any.
        const text = expression.getFullText(source);
        const matches = text.match(/^(\r?\n)(\s*)/);
        if (matches) {
            toInsert = `,${matches[1]}${core_1.tags.indentBy(matches[2].length) `${symbolName}`}`;
        }
        else {
            toInsert = `, ${symbolName}`;
        }
    }
    if (importPath !== null) {
        return [
            new change_1.InsertChange(ngModulePath, position, toInsert),
            (0, ast_utils_1.insertImport)(source, ngModulePath, symbolName.replace(/\..*$/, ''), importPath),
        ];
    }
    return [new change_1.InsertChange(ngModulePath, position, toInsert)];
}
function addModuleToFile(path, tree) {
    const recorder = tree.beginUpdate(path);
    const text = tree.read(path);
    if (text === null) {
        throw new schematics_1.SchematicsException(`The file ${path} does not exist.`);
    }
    const source = ts.createSourceFile(path, text.toString(), ts.ScriptTarget.Latest, true);
    (0, change_1.applyToUpdateRecorder)(recorder, path.includes('app.component.ts')
        ? addSymbolToNgModuleMetadata(source, path, 'imports', 'NgxLuzmoDashboardModule', '@luzmo/ngx-embed')
        : (0, ast_utils_1.addImportToModule)(source, path, 'NgxLuzmoDashboardModule', '@luzmo/ngx-embed'));
    tree.commitUpdate(recorder);
}
function addModule(projectName) {
    return (tree) => __awaiter(this, void 0, void 0, function* () {
        var _a;
        const host = createHost(tree);
        const { workspace } = yield core_1.workspaces.readWorkspace('/', host);
        const workingProjectName = (_a = projectName !== null && projectName !== void 0 ? projectName : workspace.projects.keys().next().value) !== null && _a !== void 0 ? _a : 'default';
        if (!projectName) {
            console.warn('Project name not specified, using default project:', workingProjectName);
        }
        const modulePath = '/src/app/app.module.ts';
        const appComponentPath = '/src/app/app.component.ts';
        if (tree.exists(modulePath)) {
            addModuleToFile(modulePath, tree);
        }
        else if (tree.exists(appComponentPath)) {
            // Add module to app.component.ts
            addModuleToFile(appComponentPath, tree);
        }
        else {
            throw new schematics_1.SchematicsException(`The files ${modulePath} and ${appComponentPath} does not exist.`);
        }
        return tree;
    });
}
